#
# spec file for package python-Sphinx
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           python-Sphinx
Version:        1.1.2
Release:        1.3
Url:            http://sphinx.pocoo.org
Summary:        Python documentation generator
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/S/Sphinx/Sphinx-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-docutils
BuildRequires:  python-devel
BuildRequires:  python-distribute
BuildRequires:  python-Jinja2
Requires:       python-docutils
Requires:       python-Jinja2
Requires:       python-Pygments
Requires:       python-distribute
%if 0%{?suse_version}
Suggests:       python-rst2pdf
%py_requires
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif
%endif
Provides:       python-sphinx = %{version}
Obsoletes:      python-sphinx < %{version}
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

%description
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description    doc
Sphinx is a tool that makes it easy to create intelligent and beautiful
documentation for Python projects (or other documents consisting of multiple
reStructuredText sources), written by Georg Brandl.  It was originally created
for the new Python documentation, and has excellent facilities for Python
project documentation, but C/C++ is supported as well, and more languages are
planned.

Sphinx uses reStructuredText as its markup language, and many of its strengths
come from the power and straightforwardness of reStructuredText and its parsing
and translating suite, the Docutils.

%prep
%setup -q -n Sphinx-%{version}
sed -i '1d' sphinx/pycode/pgen2/token.py # Remove she-bang line

%build
python setup.py build
cd doc && make html
rm _build/html/.buildinfo
mv _build/html ..
rm -rf _*

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
%if 0%{?suse_version} > 1010
%fdupes %{buildroot}%{_prefix}
%endif
%find_lang sphinx

%files -f sphinx.lang
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE README TODO
%{_bindir}/sphinx-*
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc EXAMPLES html

%changelog
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 1.1.2:
  * #809: Include custom fixers in the source distribution.
- Changes from version 1.1.1:
  * #791: Fix QtHelp, DevHelp and HtmlHelp index entry links.
  * #792: Include "sphinx-apidoc" in the source distribution.
  * #797: Don't crash on a misformatted glossary.
  * #801: Make intersphinx work properly without SSL support.
  * #805: Make the ``Sphinx.add_index_to_domain`` method work correctly.
  * #780: Fix Python 2.5 compatibility.
* Thu Sep 22 2011 saschpe@suse.de
- Require python-docutils instead of docutils
- Change license to BSD-2-Clause (SPDX style, according to LICENSE)
* Wed Aug 31 2011 saschpe@suse.de
- Corrected buildrequires/requires:
  * python-jinja2 is now python-Jinja2
  * python-pygments is now python-Pygments
* Tue Jul 12 2011 mcihar@suse.cz
- add python-distribute to Requires, it is needed to run sphinx-build
* Sun Jul  3 2011 saschpe@gmx.de
- Renamed to 'python-Sphinx', obsoletes 'python-sphinx'
- Update to version 1.0.7:
  * #347: Fix wrong generation of directives of static methods in
    autosummary.
  * #599: Import PIL as ``from PIL import Image``.
  * #558: Fix longtables with captions in LaTeX output.
  * Make token references work as hyperlinks again in LaTeX output.
  * #572: Show warnings by default when reference labels cannot be
    found.
  * #536: Include line number when complaining about missing reference
    targets in nitpicky mode.
  * #590: Fix inline display of graphviz diagrams in LaTeX output.
  * #589: Build using app.build() in setup command.
  * Fix a bug in the inheritance diagram exception that caused base
    classes to be skipped if one of them is a builtin.
  * Fix general index links for C++ domain objects.
  * #332: Make admonition boundaries in LaTeX output visible.
  * #573: Fix KeyErrors occurring on rebuild after removing a file.
  * Fix a traceback when removing files with globbed toctrees.
  * If an autodoc object cannot be imported, always re-read the
    document containing the directive on next build.
  * If an autodoc object cannot be imported, show the full traceback
    of the import error.
  * Fix a bug where the removal of download files and images wasn't
    noticed.
  * #571: Implement ``~`` cross-reference prefix for the C domain.
  * Fix regression of LaTeX output with the fix of #556.
  * #568: Fix lookup of class attribute documentation on descriptors
    so that comment documentation now works.
  * Fix traceback with ``only`` directives preceded by targets.
  * Fix tracebacks occurring for duplicate C++ domain objects.
  * Fix JavaScript domain links to objects with ``$`` in their name.
- Spec file cleanup:
  * Use fdupes and %%find_lang
  * Removed authors from description
  * Make doc package on require %%{version}, not %%{release}
* Wed Jan 12 2011 saschpe@suse.de
- Spec file cleanup
  * correct doc package group, no dupes
  * added rpmlintrc file
- Update to 1.0.6
  * #581: Fix traceback in Python domain for empty cross-reference
    targets.
  * #283: Fix literal block display issues on Chrome browsers.
  * #383, #148: Support sorting a limited range of accented
    characters in the general index and the glossary.
  * #570: Try decoding -D and -A command-line arguments with
    the locale's preferred encoding.
  * #528: Observe locale_dirs when looking for the JS
    translations file.
  * #574: Add special code for better support of Japanese documents
    in the LaTeX builder.
  * Regression of #77: If there is only one parameter given with
    :param: markup, the bullet list is now suppressed again.
  * #556: Fix missing paragraph breaks in LaTeX output in certain
    situations.
  * #567: Emit the autodoc-process-docstring event even for objects
    without a docstring so that it can add content.
  * #565: In the LaTeX builder, not only literal blocks require
    different table handling, but also quite a few other list-like
    block elements.
  * #515: Fix tracebacks in the viewcode extension for Python objects
    that do not have a valid signature.
  * Fix strange reportings of line numbers for warnings generated
    from autodoc-included docstrings, due to different behavior
    depending on docutils version.
  * Several fixes to the C++ domain.
* Mon Jan  3 2011 nix@opensuse.org
- Update to 1.0.5
* Wed Sep  8 2010 nix@opensuse.org
- Update to 1.0.3
* Mon Apr 26 2010 nix@opensuse.org
- Update to 0.6.5
* Tue Aug 11 2009 cfarrell@suse.de
- Update to 0.6.2 and split docs into separate package
* Fri Jun  5 2009 poeml@suse.de
- initial package (0.6.1)
